@@ -1,7 +1,7 @@
 use strict;
 use warnings;
 
-package PDK::Concerns;
+package PDK::Concern;
 
 # ABSTRACT: PDK::Concern::H3c::Netdisco - Explore and manage LLDP topology for H3C devices
 1;
